"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.templateFromString = void 0;
const template_1 = require("../../../template");
const createHash = require("create-hash");
const source_1 = require("../../../source");
/**
 * Loads a template from a string.
 *
 * <pre>
 * {{ include(template_from_string("Hello {{ name }}")) }}
 * </pre>
 *
 * @param executionContext
 * @param code
 * @param name An optional name for the template to be used in error messages
 *
 * @returns {Promise<TwingTemplate>}
 */
const templateFromString = (executionContext, code, name) => {
    const { environment } = executionContext;
    const hash = createHash("sha256").update(code).digest("hex").toString();
    if (name !== null) {
        name = `${name} (string template ${hash})`;
    }
    else {
        name = `__string_template__${hash}`;
    }
    const ast = environment.parse(environment.tokenize((0, source_1.createSource)(name, code)));
    const template = (0, template_1.createTemplate)(ast);
    return Promise.resolve(template);
};
exports.templateFromString = templateFromString;
